﻿using Microsoft.VisualBasic.FileIO;
using ProjectTourismCompany.Entities;
using ProjectTourismCompany.Entities.Enums;
using ProjectTourismCompany.Repositories;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourismCompany.Forms;

public partial class FormTrip : Form
{
    private readonly ITripRepository _tripRepository;
    private int? _tripId;
    public int Id
    {
        set
        {
            try
            {
                var trip = _tripRepository.ReadTripById(value);
                if (trip == null)
                {
                    throw new
                    InvalidDataException(nameof(trip));
                }
                textBoxStartCity.Text = trip.StartCity;
                textBoxEndCity.Text = trip.EndCity;
                numericUpDownHumanCapacity.Value = trip.HumanCapacity;
                numericUpDownPrice.Value = trip.Price;
                dateTimePickerEndDate.Value = trip.EndDate;
                dateTimePickerStartDate.Value = trip.StartDate;
                _tripId = value;

                foreach (TravelType elem in
Enum.GetValues(typeof(TravelType)))
                {
                    if ((elem & trip.TravelType) != 0)
                    {
                        checkedListBoxTravelType.SetItemChecked(checkedListBoxTravelType.Items.IndexOf(
                        elem), true);
                    }
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }
    public FormTrip(ITripRepository tripRepository)
    {
        InitializeComponent();
        _tripRepository = tripRepository ?? throw new ArgumentNullException(nameof(tripRepository));
        foreach (var elem in Enum.GetValues(typeof(TravelType)))
        {
            checkedListBoxTravelType.Items.Add(elem);
        }

    }
    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrWhiteSpace(textBoxStartCity.Text) ||
            string.IsNullOrWhiteSpace(textBoxEndCity.Text))
            {
                throw new Exception("Имеются незаполненные поля");
            }

            if (_tripId.HasValue)
            {
                _tripRepository.CreateTrip(CreateTrip(_tripId.Value));
            }
            else
            {
                _tripRepository.CreateTrip(CreateTrip(0));
            }

            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
    private void ButtonCancel_Click(object sender, EventArgs e) =>
    Close();

    private Trip CreateTrip(int id)
    {
        TravelType tr = TravelType.None;
        foreach (var elem in checkedListBoxTravelType.CheckedItems)
        {
            tr |= (TravelType)elem;
        }
        return Trip.CreateOpeartion(id, textBoxTitle.Text, (int)numericUpDownPrice.Value,
                (int)numericUpDownHumanCapacity.Value, dateTimePickerStartDate.Value, dateTimePickerEndDate.Value,
                textBoxStartCity.Text, textBoxEndCity.Text, tr);
    }
}
